@@ -32,9 +32,27 @@
 {
   cx <- class(x)
   value <- as.rvobj(value)
-  x <- unclass(x)
-  X <- .Primitive("[<-")(x, ..., value=value)
+  X <- .Primitive("[<-")(unclass(x), ..., value=value)
   class(X) <- cx
   return(X)
 }
 
+"impute<-" <- function(x, ..., value) {
+  if (! is.rvobj(x) && ! is.rvobj(value)) {
+    x[...] <- value
+  } else if (is.rvsummary(x) || is.rvsummary(value)) {
+    x <- as.rvsummary(x)
+    value <- as.rvsummary(value)
+    x[...] <- value
+  } else if (is.rv(x) || is.rv(value)) {
+    x <- as.rv(x)
+    value <- as.rv(value)
+    x[...] <- value
+  }
+  return(x)
+}
+
+
+
+
+
